@@ -60,7 +60,7 @@ class AppService(Service):
 
     def load_access_key(self):
         logger.error("Load access key")
-        self.access_key.load()
+        # self.access_key.load()
         if not self.access_key:
             logger.info("No access key found, register it")
             self.register_and_save()
@@ -91,7 +91,8 @@ class AppService(Service):
             sys.exit()
 
     def register_and_save(self):
-        wt_name = '[' + self.config['NAME'] + ']' + socket.gethostname()
+        logger.error('bootstrap token {0}'.format(self.config['BOOTSTRAP_TOKEN']))
+        wt_name = '[' + self.config['NAME'] + ']' + socket.gethostbyname(socket.gethostname())
         terminal = self.register_terminal_v2(
             wt_name, self.config['BOOTSTRAP_TOKEN']
         )
